@@ -9,5 +9,5 @@ Desc: 数据分布画图
 '''
 
 
-from .trajectory_playback import Trajectory
-from .trajectory_playback_v2 import Trajectory as Trajectory_tmp
\ No newline at end of file
+from .trajectory_playback import Trajectory as Trajectory_his
+from .trajectory_playback_v2 import Trajectory as Trajectory
\ No newline at end of file
