@@ -23,6 +23,7 @@ pattern_triplist=re.compile(r"(?<=var tripList = ).*?(?=;$)",re.MULTILINE | re.D
 pattern_markerlist=re.compile(r"(?<=var markerArr = ).*?(?=;$)",re.MULTILINE | re.DOTALL)
 pattern_automarker=re.compile(r"(?<=var auto_marker = ).*?(?=;$)",re.MULTILINE | re.DOTALL)
 
+CURRENT_PATH = os.path.dirname(os.path.abspath(__file__))
 class Trajectory():
     def __init__(self, lnglat_arr=[], trip_list=[], auto_marker=True):
         self.js=get_main_js()
@@ -73,7 +74,7 @@ class Trajectory():
             webbrowser.open(url='file://' + self.html_name, new=0, autoraise=True)
 
 def get_main_js():
-    filename= os.path.abspath('pynovice_map.js')
+    filename= os.path.join(CURRENT_PATH,'pynovice_map.js')
     with open(filename,'r') as f:
         main_js = f.read()
     return main_js
